/*
    Copyright (c) 2015 digitalSTROM AG, Zurich, Switzerland

    This file is part of dS Assistant.

    dS-Assistant is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    dS-Assistant is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with digitalSTROM Server. If not, see <http://www.gnu.org/licenses/>.

    NOTE: all APIs, especially the JSON API, offered by this application
          are subject to change without further notice.
*/

#ifndef __HWDESC_ATTRIBUTES_H__
#define __HWDESC_ATTRIBUTES_H__

#include <inttypes.h>
#include <cstddef>

const int MIN_TEMP = -2732; //< -273.15 C
const int MAX_TEMP = 1490; //< 149.00 C

/**
 * @attr -- attribute as retrieved with the dsm-api
 * @ret  -- temperature in deci celsius, e.g. 109 dC -> 10.9 C
 */
int attributeToTemperature(uint16_t attr);

/*
 * Charging Pulse
 *
 * The time interval where the device consumes power
 * during each AC period.
 */
typedef struct
{
    uint8_t LOAD1;
    uint8_t LOAD2;
} cp_parameters_t;

const cp_parameters_t charging_pulse_table[] = {
    { 0x00, 0x8C }, // 0, cooler slots, devices will heat up less
    { 0x00, 0x8A },
    { 0x00, 0x89 },
    { 0x00, 0x88 },
    { 0x00, 0x87 },
    { 0x00, 0x86 },
    { 0x00, 0x85 },
    { 0x00, 0x84 },
    { 0x00, 0x83 },
    { 0x00, 0x82 },
    { 0x00, 0x81 }, // 10
    { 0x00, 0x80 },
    { 0x00, 0x7F },
    { 0x00, 0x7E },
    { 0x00, 0x7D },
    { 0x00, 0x7C },
    { 0x00, 0x7B },
    { 0x00, 0x7A },
    { 0x00, 0x79 },
    { 0x00, 0x78 },
    { 0x00, 0x77 }, // 20
    { 0x00, 0x76 },
    { 0x00, 0x75 },
    { 0x00, 0x74 },
    { 0x00, 0x73 },
    { 0x00, 0x72 },
    { 0x00, 0x71 },
    { 0x00, 0x70 },
    { 0x00, 0x6F },
    { 0x00, 0x6E },
    { 0x00, 0x6D }, // 30
    { 0x00, 0x6C },
    { 0x00, 0x6B },
    { 0x00, 0x6A },
    { 0x00, 0x69 },
    { 0x00, 0x68 },
    { 0x00, 0x67 },
    { 0x00, 0x66 },
    { 0x00, 0x65 },
    { 0x00, 0x64 }, // hotter slots, devices will heat up more
};

extern const size_t charge_slot_count;

#endif
